@@ -5,7 +5,6 @@ from traceback import format_exc
 from .errors import Error
 from .version import version
 from .utils import tryimport
-from .states import NormalState
 from .parser import parse, tokenize
 
 from .block import Block
@@ -36,7 +35,6 @@ class State(object):
             self.args = []
 
         self._value = None
-        self._state = NormalState()
 
     @property
     def value(self):
@@ -46,20 +44,6 @@ class State(object):
     def value(self, value):
         self._value = value
 
-    @property
-    def state(self):
-        return self._state
-
-    @property
-    def stop(self):
-        return self.state.isBreak or self.state.isContinue or self.state.isReturn
-
-    def reset(self):
-        self._state = NormalState()
-
-    def set(self, state):
-        self._state = state
-
     def create_objects(self):
         root = self.root
 
@@ -133,7 +117,7 @@ class State(object):
                 code = raw_input(">>> ")
                 if code:
                     result = self.eval(code)
-                    if result is not None:
+                    if result is not None and result.value is not None:
                         print("==> {0:s}".format(self.eval("repr", receiver=result)))
             except EOFError:
                 raise SystemExit(0)
