@@ -1,6 +1,7 @@
 from pytest import raises
 
 from mio import runtime
+from mio.utils import format_object
 from mio.errors import AttributeError, TypeError
 
 
@@ -50,6 +51,27 @@ def test_foreach(mio):
     assert mio.eval("sum(xs)") == 6
 
 
+def test_while(mio):
+    assert mio.eval("xs = List clone") == []
+    assert mio.eval("xs append(1)") == [1]
+    assert mio.eval("xs append(2)") == [1, 2]
+    assert mio.eval("xs append(3)") == [1, 2, 3]
+
+    mio.eval("""
+        sum = method(xs,
+            i = 0
+            sum = 0
+            while (i < xs len,
+                sum = sum + xs at(i)
+                i += 1
+            )
+            sum
+        )
+    """)
+
+    assert mio.eval("sum(xs)") == 6
+
+
 def test_forward(mio):
     mio.eval("Foo = Object clone")
     assert mio.eval("Foo x = 1")
@@ -121,8 +143,10 @@ def test_neq(mio):
     assert mio.eval("1 !=(0)").value is True
 
 
-def test_println(mio):
-    pass
+def test_println(mio, capsys):
+    assert mio.eval("\"Hello World!\" println") == "Hello World!"
+    out, err = capsys.readouterr()
+    assert out == "Hello World!\n"
 
 
 def test_set(mio):
@@ -192,13 +216,34 @@ def test_str(mio):
     pass
 
 
-def test_summary(mio):
-    pass
+def test_summary(mio, capsys):
+    mio.eval("Foo = Object clone")
+    assert mio.eval("Foo x = 1")
+
+    assert mio.eval("Foo summary") == mio.eval("Foo")
+    out, err = capsys.readouterr()
+    assert out == "{0:s}\n".format(format_object(mio.eval("Foo")))
 
 
-def test_write(mio):
-    pass
+def test_write(mio, capsys):
+    assert mio.eval("write(\"Hello World!\")").value is None
+    out, err = capsys.readouterr()
+    assert out == "Hello World!"
 
 
-def test_writeln(mio):
-    pass
+def test_write2(mio, capsys):
+    assert mio.eval("write(\"a\", \"b\", \"c\")").value is None
+    out, err = capsys.readouterr()
+    assert out == "abc"
+
+
+def test_writeln(mio, capsys):
+    assert mio.eval("writeln(\"Hello World!\")").value is None
+    out, err = capsys.readouterr()
+    assert out == "Hello World!\n"
+
+
+def test_writeln2(mio, capsys):
+    assert mio.eval("writeln(\"a\", \"b\", \"c\")").value is None
+    out, err = capsys.readouterr()
+    assert out == "abc\n"
